@@ -115,7 +115,7 @@ class HapiJpaStarterAction(Action[HapiJpaStarterState]):
         self.maven_home = self.state.path / MAVEN_DIR
 
         mvn_local_repo = Path(state.params.mvn_local_repo)
-        if mvn_local_repo.absolute():
+        if mvn_local_repo.is_absolute():
             self.maven_repo = mvn_local_repo
         else:
             self.maven_repo = self.state.path / mvn_local_repo
